@@ -6,7 +6,7 @@ data("GasolineYield", package = "zoib")
 eg.fixed <- zoib(yield ~ temp + as.factor(batch)| 1, data=GasolineYield,
                  joint = FALSE,  random = 0, EUID = 1:nrow(d),
                  zero.inflation = FALSE, one.inflation = FALSE,
-                 n.iter = 41, n.thin = 2, n.burn=1, seeds=c(1,2,3),n.chain=3)
+                 n.iter = 151, n.thin = 2, n.burn=1, seeds=c(1,2),n.chain=2)
 sample1 <- eg.fixed$coeff
 
 
